"use strict";

var omitBy = require("./omitBy.cjs");

/**
 * The opposite of `_.pick`; this method creates an object composed of the
 * own and inherited enumerable property paths of `object` that are not omitted.
 *
 * **Note:** This method is considerably slower than `_.pick`.
 *
 * @param {Object} object The source object.
 * @param {...(string|string[])} paths The property paths to omit.
 * @returns {Object} Returns the new object.
 */
module.exports = omit;

function omit(object) {
  for (var _len = arguments.length, paths = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    paths[_key - 1] = arguments[_key];
  }

  var omit = paths.some(arg => Array.isArray(arg)) ? paths.length === 1 ? paths[0] : [].concat(...paths) : paths;
  return omitBy(object, (_, key) => omit.includes(key));
}