"use strict";

/**
 * Creates an object composed of the picked `object` properties.
 *
 * @param {Object} object The source object.
 * @param {...(string|string[])} paths The property paths to pick.
 * @returns {Object} Returns the new object.
 */
module.exports = pick;

function pick(object) {
  for (var _len = arguments.length, paths = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    paths[_key - 1] = arguments[_key];
  }

  var pick = paths.some(path => Array.isArray(path)) ? paths.length === 1 ? paths[0] : [].concat(...paths) : paths;
  var result = {};

  for (var key of pick) {
    if (key in object) result[key] = object[key];
  }

  return result;
}