"use strict";

var identity = require("./identity.cjs");

var isPrototype = require("./_isPrototype.cjs");

/**
 * Creates an object composed of the `object` properties `predicate` returns
 * truthy for. The predicate is invoked with two arguments: (value, key).
 *
 * @param {Object} object The source object.
 * @param {(value: any, key: string) => boolean} [predicate=_.identity] The function invoked per property.
 * @returns {Object} Returns the new object.
 */
module.exports = pickBy;

function pickBy(object) {
  var predicate = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : identity;
  var result = {};

  for (var key in object) {
    if ((key !== 'constructor' || !isPrototype(object) || hasOwnProperty.call(object, key)) && predicate(object[key], key)) {
      result[key] = object[key];
    }
  }

  return result;
}