export default function throttle(fnc, time) {
  var timeout;
  var lastCall;
  var lastValue;

  function call() {
    lastCall = Date.now();
    clearTimeout(timeout);
    return fnc(...arguments);
  }

  return function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    if (!timeout && !lastCall || lastCall + time < Date.now()) {
      lastValue = call(...args);
      return lastValue;
    }

    clearTimeout(timeout);
    timeout = setTimeout(() => call(...args), time - (Date.now() - lastCall));
    return lastValue;
  };
}